@@ -30,6 +30,7 @@ urlpatterns = [
     re_path(r'^group/?(?P<user_group_id>\d+)?$', GroupAPIView.as_view()),  # 分组 增加（post）/删除(delete)/修改(edit)
     re_path(r'^user_group_list/?$', GroupAPIView.user_group_list),  # 用户分组列表
     re_path(r'^user_group_tree/?$', GroupAPIView.user_group_tree),
+
     # 用户分组树，原为role_group_tree，命名难以理解，改为role_user_group_tree
     re_path(r'^group_tree_role/?$', GroupAPIView.group_tree_role),  # 分组 角色树
     re_path(r'^group_tree_user/?$', GroupAPIView.group_tree_user),  # 分组 用户树
@@ -38,7 +39,8 @@ urlpatterns = [
     re_path(r'^group_user_add/?$', GroupAPIView.group_user_add),  # 分组 用户添加
     re_path(r'^group_user_edit/?$', GroupAPIView.group_user_edit),  # 分组 用户修改
     re_path(r'^group_user_delete/?$', GroupAPIView.group_user_delete),  # 分组 用户删除
+
     # re_path(r'^bind_user_role/?$', GroupAPIView.bind_user_role),  # 用户角色那绑定
-    re_path(r'^bind_user_group/?$', GroupAPIView.bind_user_group),  # 用户分组绑定
+    re_path(r'^bind_user_group/?$', GroupAPIView.user_bind_groups),  # 用户分组绑定
 
 ]
